@@ -349,9 +349,11 @@ class MDG(Tk):
             main_db_path = os.path.dirname(main_db_path)
 
         self.__pointer = pointer
-        self.__local_db_dir = local_db_dir
+        self.__local_dir = local_dir
         self.__main_db_path = StringVar()
         self.__main_db_dir = StringVar()
+        self.__local_db_path = StringVar()
+        self.__local_db_dir = StringVar()
 
         if main_db_path:
             self.__main_db_path.set(main_db_path)
@@ -367,11 +369,11 @@ class MDG(Tk):
         return self.__pointer
 
     def __build(self):
-        header = ['Welcome to main database setup!', 'Please fill out the below fields to setup']
-        header2 = ['Welcome to existing main database setup!', 'Please fill out the below fields to setup']
+        header = ['Welcome to new database setup!', 'Please fill out the below fields to setup']
+        header2 = ['Welcome to existing database setup!', 'Please fill out the below fields to setup']
 
         # Set GUI Geometry and GUI Title
-        self.geometry('280x160+550+150')
+        self.geometry('280x215+550+150')
         self.title('Main Database Setup')
         self.resizable(False, False)
 
@@ -383,10 +385,10 @@ class MDG(Tk):
         t.add(existing_tab, text='Existing')
 
         new_header_frame = Frame(new_tab)
-        new_settings_frame = LabelFrame(new_tab, text='Main DB', width=508, height=70)
+        new_settings_frame = LabelFrame(new_tab, text='Create DBs', width=508, height=70)
         new_buttons_frame = Frame(new_tab)
         existing_header_frame = Frame(existing_tab)
-        existing_main_frame = LabelFrame(existing_tab, text='Main DB', width=508, height=70)
+        existing_main_frame = LabelFrame(existing_tab, text='Find DBs', width=508, height=70)
         existing_buttons_frame = Frame(existing_tab)
 
         # Apply Frames into GUI
@@ -406,7 +408,7 @@ class MDG(Tk):
 
         # Apply Widgets to new_settings_frame
         #    Apply Settings Directory Entry Box Widget
-        settings_dir_label = Label(new_settings_frame, text='DB Dir:')
+        settings_dir_label = Label(new_settings_frame, text='Main DB Dir:')
         settings_dir_entry = Entry(new_settings_frame, textvariable=self.__main_db_dir)
         settings_dir_label.grid(row=0, column=0, padx=4, pady=5)
         settings_dir_entry.grid(row=0, column=1, padx=4, pady=5)
@@ -415,6 +417,16 @@ class MDG(Tk):
         find_settings_dir_button = Button(new_settings_frame, text='...', width=8, command=self.__main_dir_gui)
         find_settings_dir_button.grid(row=0, column=2, padx=4, pady=5)
 
+        #    Apply Settings Directory Entry Box Widget
+        settings_dir_label = Label(new_settings_frame, text='Local DB Dir:')
+        settings_dir_entry = Entry(new_settings_frame, textvariable=self.__local_db_dir)
+        settings_dir_label.grid(row=1, column=0, padx=4, pady=5)
+        settings_dir_entry.grid(row=1, column=1, padx=4, pady=5)
+
+        #   Apply Settings Directory Finder Button Widget
+        find_settings_dir_button = Button(new_settings_frame, text='...', width=8, command=self.__local_dir_gui)
+        find_settings_dir_button.grid(row=1, column=2, padx=4, pady=5)
+
         # Apply Buttons to the new_buttons_frame
         #     Generate button
         generate_button = Button(self, text='Generate', width=15, command=self.__generate)
@@ -426,18 +438,28 @@ class MDG(Tk):
 
         # Apply Widgets to existing_frame
         #   Apply Main Filepath Entry Box Widget
-        settings_fp_label = Label(existing_main_frame, text='DB Fp:')
+        settings_fp_label = Label(existing_main_frame, text='Main DB Fp:')
         settings_fp_entry = Entry(existing_main_frame, textvariable=self.__main_db_path)
+        settings_fp_label.grid(row=0, column=0, padx=4, pady=5)
+        settings_fp_entry.grid(row=0, column=1, padx=4, pady=5)
+
+        #   Apply Main Filepath Finder Button Widget
+        find_settings_name_button = Button(existing_main_frame, text='...', width=3, command=self.__main_file_gui)
+        find_settings_name_button.grid(row=0, column=2, padx=4, pady=5)
+
+        #   Apply Main Filepath Entry Box Widget
+        settings_fp_label = Label(existing_main_frame, text='Local DB Fp:')
+        settings_fp_entry = Entry(existing_main_frame, textvariable=self.__local_db_path)
         settings_fp_label.grid(row=1, column=0, padx=4, pady=5)
         settings_fp_entry.grid(row=1, column=1, padx=4, pady=5)
 
         #   Apply Main Filepath Finder Button Widget
-        find_settings_name_button = Button(existing_main_frame, text='...', width=3, command=self.__main_file_gui)
+        find_settings_name_button = Button(existing_main_frame, text='...', width=3, command=self.__local_file_gui)
         find_settings_name_button.grid(row=1, column=2, padx=4, pady=5)
 
         # Apply Buttons to the existing_buttons_frame
         #     Generate button
-        generate_button = Button(self, text='Link DB', width=15, command=self.__generate2)
+        generate_button = Button(self, text='Link DBs', width=15, command=self.__generate2)
         generate_button.pack(in_=existing_buttons_frame, side=LEFT, padx=7, pady=7)
 
         #     Cancel button
@@ -452,19 +474,30 @@ class MDG(Tk):
         if self.__main_db_dir.get() and os.path.exists(self.__main_db_dir.get()):
             init_dir = self.__main_db_dir.get()
         else:
-            init_dir = self.__local_db_dir
+            init_dir = self.__local_dir
 
         settings_dir = filedialog.askdirectory(initialdir=init_dir, title='Select Main DB Directory', parent=self)
 
         if settings_dir:
             self.__main_db_dir.set(settings_dir)
 
+    def __local_dir_gui(self):
+        if self.__local_db_dir.get() and os.path.exists(self.__local_db_dir.get()):
+            init_dir = self.__local_db_dir.get()
+        else:
+            init_dir = self.__local_dir
+
+        settings_dir = filedialog.askdirectory(initialdir=init_dir, title='Select Local DB Directory', parent=self)
+
+        if settings_dir:
+            self.__local_db_dir.set(settings_dir)
+
     def __main_file_gui(self):
         if self.__main_db_path.get() and os.path.exists(self.__main_db_path.get()):
             init_dir = os.path.dirname(self.__main_db_path.get())
             init_file = os.path.basename(self.__main_db_path.get())
         else:
-            init_dir = self.__local_db_dir
+            init_dir = self.__local_dir
             init_file = ''
 
         settings_name = filedialog.askopenfile(initialdir=init_dir, initialfile=init_file,
@@ -475,6 +508,22 @@ class MDG(Tk):
             self.__main_db_path.set(settings_name.name)
             settings_name.close()
 
+    def __local_file_gui(self):
+        if self.__local_db_path.get() and os.path.exists(self.__local_db_path.get()):
+            init_dir = os.path.dirname(self.__local_db_path.get())
+            init_file = os.path.basename(self.__local_db_path.get())
+        else:
+            init_dir = self.__local_dir
+            init_file = ''
+
+        settings_name = filedialog.askopenfile(initialdir=init_dir, initialfile=init_file,
+                                               title='Select Local DB', filetypes=[("db files", "*.db")],
+                                               parent=self)
+
+        if settings_name:
+            self.__local_db_path.set(settings_name.name)
+            settings_name.close()
+
     def __generate2(self):
         if not self.__main_db_path:
             showerror('Field Empty Error!', 'No value has been inputed for Main DB Path', parent=self)
@@ -482,15 +531,21 @@ class MDG(Tk):
             showerror('Invalid Path Error!', 'Main DB Path is not a file or directory!', parent=self)
         elif not os.path.exists(self.__main_db_path.get()):
             showerror('Path Exist Error!', 'Main DB Path does not exist!', parent=self)
+        elif not self.__local_db_path:
+            showerror('Field Empty Error!', 'No value has been inputed for Local DB Path', parent=self)
+        elif not os.path.isfile(self.__local_db_path.get()) and not os.path.isdir(self.__local_db_path.get()):
+            showerror('Invalid Path Error!', 'Local DB Path is not a file or directory!', parent=self)
+        elif not os.path.exists(self.__local_db_path.get()):
+            showerror('Path Exist Error!', 'Local DB Path does not exist!', parent=self)
         else:
             if not self.__pointer:
                 from .data import DataConfig
 
-                self.__pointer = DataConfig(file_dir=self.__local_db_dir, file_name_prefix='Script_Pointer',
+                self.__pointer = DataConfig(file_dir=self.__local_dir, file_name_prefix='Script_Pointer',
                                             file_ext='ptr', encrypt=True)
 
-            self.__pointer.setcrypt(key='Local_DB_Path', val=os.path.join(self.__local_db_dir, 'Local_Settings.db'),
-                                    private=True)
+            self.__pointer.setcrypt(key='Local_DB_Path', val=os.path.join(self.__local_db_path.get(),
+                                                                          'Local_Settings.db'), private=True)
 
             if os.path.isfile(self.__main_db_path.get()):
                 self.__pointer.setcrypt(key='Main_DB_Path', val=self.__main_db_path.get(), private=True)
@@ -507,15 +562,21 @@ class MDG(Tk):
             showerror('Invalid Directory!', 'Main DB Directory is an invalid directory', parent=self)
         elif not os.path.exists(self.__main_db_dir.get()):
             showerror('Directory Not Exist!', 'Main DB Directory does not exist', parent=self)
+        elif not self.__local_db_dir:
+            showerror('Field Empty Error!', 'No value has been inputed for Local DB Directory', parent=self)
+        elif not os.path.isdir(self.__local_db_dir.get()):
+            showerror('Invalid Directory!', 'Local DB Directory is an invalid directory', parent=self)
+        elif not os.path.exists(self.__local_db_dir.get()):
+            showerror('Directory Not Exist!', 'Local DB Directory does not exist', parent=self)
         else:
             if not self.__pointer:
                 from .data import DataConfig
 
-                self.__pointer = DataConfig(file_dir=self.__local_db_dir, file_name_prefix='Script_Pointer',
+                self.__pointer = DataConfig(file_dir=self.__local_dir, file_name_prefix='Script_Pointer',
                                             file_ext='ptr', encrypt=True)
 
-            self.__pointer.setcrypt(key='Local_DB_Path', val=os.path.join(self.__local_db_dir, 'Local_Settings.db'),
-                                    private=True)
+            self.__pointer.setcrypt(key='Local_DB_Path', val=os.path.join(self.__local_db_dir.get(),
+                                                                          'Local_Settings.db'), private=True)
             self.__pointer.setcrypt(key='Main_DB_Path', val=os.path.join(self.__main_db_dir.get(), 'Main_Settings.db'),
                                     private=True)
             self.__pointer.sync()
