@@ -89,7 +89,7 @@ class TBoxBase(object):
         """
 
         if self.__pointer and 'Local_DB_Path' in pointer.keys():
-            return self.__pointer['Local_DB_Path'].decrypt()
+            return dirname(self.__pointer['Local_DB_Path'].decrypt())
         else:
             return None
 
@@ -157,22 +157,27 @@ class TBoxBase(object):
 class Toolbox(TBoxBase, SQLQueue, LogHandle):
     DEFAULT_CONNECTION_SIZE = 10
 
-    def __init__(self, script_path, logging_dir=None, logging_base_name=None, max_pool_size=None,
-                 *args, **kwargs):
+    def __init__(self, script_path, logging_dir=None, logging_base_name=None, max_pool_size=None, *args, **kwargs):
+        TBoxBase.__init__(self, script_path=script_path)
+        SQLQueue.__init__(self, max_pool_size=max_pool_size)
+        LogHandle.__init__(self)
+
+        file_dir = None
+        base_name = None
+
         if logging_dir and os.path.exists(logging_dir) and os.path.isdir(logging_dir):
             file_dir = logging_dir
+        elif self.local_config_dir:
+            file_dir = self.local_config_dir
 
+        if file_dir:
             if logging_base_name:
                 base_name = os.path.basename(logging_base_name)
             else:
                 base_name = os.path.basename(script_path)
-        else:
-            file_dir = None
-            base_name = None
 
-        TBoxBase.__init__(self, script_path=script_path)
-        SQLQueue.__init__(self, max_pool_size=max_pool_size)
-        LogHandle.__init__(self, file_dir=file_dir, base_name=base_name)
+            self.file_dir = file_dir
+            self.base_name = base_name
 
     def config_sql_conn(self, sql_config, new_instance=False, conn_max_pool_size=DEFAULT_CONNECTION_SIZE):
         """
